<?php
/**
 * @author Björn Ahrens
 * @package WP Performance Pack
 * @since 2.2
 */

class WPPP_Disable_Widgets extends WPPP_Module {
	private $known_default_widgets = NULL;
	private $default_widget_loaded = false;

	public function load_renderer () {
		if ( $this->wppp->options['advanced_admin_view'] ) {
			return new WPPP_Disable_Widgets_Advanced( $this->wppp );
		} else {
			return new WPPP_Disable_Widgets_Simple( $this->wppp );
		}
	}

	function early_init () {
		$this->known_default_widgets = $this->wppp->get_option( 'wppp_known_default_widgets' );

		// prevents "wp-includes/default-widgets.php" from loading (used in "wp-includes/functions.php /wp_maybe_load_widgets")
		add_filter( 'load_default_widgets', '__return_false' );
		// This action (function defined in "wp-includes/widgets.php") would try to register all widget class from "default-widgets.php"
		remove_action( 'init', 'wp_widgets_init', 1 );
		// removing the original action also removes firing the action "widgets_init"
		// so always add the override that will at least fires "widgets_init"
		add_action( 'init', array( $this, 'init_wp_default_widgets' ), 1 );
	}

	function init_wp_default_widgets() {
		// Fires after all default WordPress widgets have been registered.
		foreach( $this->known_default_widgets as $widget => $files ) {
			if ( !in_array( $widget, $this->wppp->options[ 'disabled_widgets' ] ) ) {
				foreach ( $files as $file )
					include_once( ABSPATH . WPINC . '/widgets/' . $file );
				register_widget( $widget );
				$this->default_widget_loaded = true;
			}
		}

		// because "load_default_widgets" in early_init did return false, the widget submenu wasn't added
		// so add the menu if any widget was added or if any other plugin or theme already has added a widget
		//if ( $this->default_widget_loaded ) 
			add_action( '_admin_menu', 'wp_widgets_add_menu' );
		
		do_action( 'widgets_init' );	
	}

	function validate_options( &$input, $output, $default ) {
		// settings form returns in wppp_options[ 'enable_widgets' ] an array of all enabled widgets,
		// but the settings save disabled widgets
		$disabled = array();
		foreach( $this->known_default_widgets as $widget => $files ) {
			if ( !isset( $input[ 'disabled_widgets' ] ) || !in_array( $widget, $input[ 'disabled_widgets' ] ) )
				$disabled[] = $widget;
		}
		$input[ 'disabled_widgets' ] = $disabled;
		$output = parent::validate_options( $input, $output, $default );
		return $output;
	}
}